HitchVagrant
============

HitchVagrant is a plugin for the Hitch test framework that lets you run
vagrant as a hitch service.

See docs: https://hitchtest.readthedocs.org/en/latest/services/vagrant.html
